@@ -10,6 +10,8 @@ import logging.config
 import signal
 import json
 import traceback
+import atexit
+from pathlib import Path
 from urllib.parse import urljoin
 
 # Configure NumExpr for thread safety BEFORE any imports that might use NumPy/pandas
@@ -34,6 +36,73 @@ RETRY_DELAY = 5  # Delay in seconds between retry attempts
 AUTH_ERROR_DELAY = 15  # Delay in seconds after authentication error before requesting new credentials
 MAX_AUTH_RETRIES = 20
 
+# PID file for web dashboard
+_WEB_PID_FILE = Path('./data/insyt-audit-web.pid')
+
+
+def _kill_web_dashboard():
+    """Kill the web dashboard process if it's running (reads PID from file)."""
+    if not _WEB_PID_FILE.exists():
+        logger.debug("No web dashboard PID file found, skipping cleanup")
+        return
+    
+    try:
+        with open(_WEB_PID_FILE, 'r') as f:
+            web_pid = int(f.read().strip())
+        
+        logger.info(f"Found web dashboard process (PID: {web_pid}), stopping it...")
+        
+        try:
+            # Try to kill the process
+            os.kill(web_pid, signal.SIGTERM)
+            
+            # Wait a moment for graceful shutdown
+            time.sleep(1)
+            
+            # Check if process is still alive
+            try:
+                os.kill(web_pid, 0)  # Signal 0 just checks if process exists
+                # Process still alive, force kill
+                logger.warning(f"Web dashboard didn't stop gracefully, force killing...")
+                os.kill(web_pid, signal.SIGKILL)
+                time.sleep(0.5)
+            except ProcessLookupError:
+                # Process is already dead, good
+                pass
+            
+            logger.info("Web dashboard stopped successfully")
+            
+        except ProcessLookupError:
+            # Process doesn't exist
+            logger.debug(f"Web dashboard process {web_pid} not found (may have already exited)")
+        except PermissionError:
+            logger.error(f"Permission denied to kill web dashboard process {web_pid}")
+        except Exception as e:
+            logger.error(f"Error killing web dashboard process: {e}")
+        
+        # Always try to clean up PID file
+        try:
+            if _WEB_PID_FILE.exists():
+                _WEB_PID_FILE.unlink()
+                logger.debug("Web dashboard PID file removed")
+        except Exception as e:
+            logger.warning(f"Failed to remove PID file: {e}")
+        
+    except ValueError as e:
+        logger.error(f"Invalid PID in file: {e}")
+        # Remove corrupted PID file
+        try:
+            _WEB_PID_FILE.unlink()
+        except:
+            pass
+    except Exception as e:
+        logger.warning(f"Failed to stop web dashboard: {e}")
+
+
+# Register cleanup function to run on exit
+atexit.register(_kill_web_dashboard)
+
+
 # Note: keep this function for backward compatibility. 
 # The ProjectManager now has its own implementation to avoid circular imports.
 def get_credentials(project_id, api_url, api_key=None):
@@ -302,6 +371,12 @@ async def main():
         # Log startup message
         logger.info("Insyt Secure Execution Service starting up")
         
+        # Clean up any stale web dashboard process from previous run
+        # This handles cases where the main service crashed and didn't clean up
+        if _WEB_PID_FILE.exists():
+            logger.info("Found stale web dashboard PID file from previous run, cleaning up...")
+            _kill_web_dashboard()
+        
         # Parse network security settings
         allowed_hosts = None
         if args.allowed_hosts:
