@@ -484,7 +484,8 @@ class ProjectManager:
                         allowed_ips=self.allowed_hosts,
                         always_allowed_domains=self.always_allowed_domains,
                         max_workers=self.max_workers.get(project_id, 5),
-                        execution_timeout=self.timeout.get(project_id, 30)
+                        execution_timeout=self.timeout.get(project_id, 30),
+                        project_id=project_id
                     )
                     # Use shared DNS cache
                     executor.dns_cache = self.dns_cache
