@@ -55,6 +55,7 @@ class AuditLogger:
                     timestamp DATETIME DEFAULT CURRENT_TIMESTAMP,
                     user TEXT NOT NULL,
                     group_name TEXT,
+                    project_id TEXT,
                     query_compressed BLOB,
                     python_code_compressed BLOB,
                     extracted_data_compressed BLOB,
@@ -82,7 +83,40 @@ class AuditLogger:
             """)
             
             conn.commit()
-            logger.info(f"Audit database initialized at {self.db_path}")
+        
+        # Perform migration: Add project_id column if it doesn't exist
+        # Note: This also creates the idx_project index
+        self._migrate_add_project_id()
+        
+        logger.info(f"Audit database initialized at {self.db_path}")
+    
+    def _migrate_add_project_id(self):
+        """Add project_id column to existing databases (migration)."""
+        try:
+            with sqlite3.connect(self.db_path) as conn:
+                cursor = conn.cursor()
+                
+                # Check if project_id column exists
+                cursor.execute("PRAGMA table_info(execution_logs)")
+                columns = [row[1] for row in cursor.fetchall()]
+                
+                if 'project_id' not in columns:
+                    logger.info("Migrating database: Adding project_id column to execution_logs")
+                    cursor.execute("""
+                        ALTER TABLE execution_logs 
+                        ADD COLUMN project_id TEXT
+                    """)
+                    
+                    # Create index for the new column
+                    cursor.execute("""
+                        CREATE INDEX IF NOT EXISTS idx_project 
+                        ON execution_logs(project_id)
+                    """)
+                    
+                    conn.commit()
+                    logger.info("Database migration completed: project_id column added")
+        except Exception as e:
+            logger.error(f"Error during database migration: {str(e)}")
     
     @staticmethod
     def _compress(data: Optional[str]) -> Optional[bytes]:
@@ -105,6 +139,7 @@ class AuditLogger:
         user: str,
         status: str,
         group: Optional[str] = None,
+        project_id: Optional[str] = None,
         extracted_data: Optional[str] = None,
         error_message: Optional[str] = None
     ) -> int:
@@ -115,10 +150,11 @@ class AuditLogger:
             query: User's natural language query
             python_code: Generated Python code
             user: Username who executed the query
-            status: Execution status ('success' or 'failed')
+            status: Execution status ('success' or 'failure')
             group: User's group/team affiliation (optional)
+            project_id: Project identifier (optional)
             extracted_data: Data returned from execution (optional)
-            error_message: Error message if status is 'failed' (optional)
+            error_message: Error message if status is 'failure' (optional)
             
         Returns:
             Log entry ID
@@ -132,10 +168,10 @@ class AuditLogger:
             cursor = conn.cursor()
             cursor.execute("""
                 INSERT INTO execution_logs 
-                (user, group_name, query_compressed, python_code_compressed, 
+                (user, group_name, project_id, query_compressed, python_code_compressed, 
                  extracted_data_compressed, status, error_message)
-                VALUES (?, ?, ?, ?, ?, ?, ?)
-            """, (user, group, query_compressed, code_compressed, 
+                VALUES (?, ?, ?, ?, ?, ?, ?, ?)
+            """, (user, group, project_id, query_compressed, code_compressed, 
                   data_compressed, status, error_message))
             
             log_id = cursor.lastrowid
@@ -239,6 +275,7 @@ class AuditLogger:
         offset: int = 0,
         users: Optional[List[str]] = None,
         groups: Optional[List[str]] = None,
+        project_ids: Optional[List[str]] = None,
         statuses: Optional[List[str]] = None,
         date_from: Optional[datetime] = None,
         date_to: Optional[datetime] = None
@@ -251,6 +288,12 @@ class AuditLogger:
             offset: Offset for pagination
             users: Filter by users (optional)
             groups: Filter by groups (optional)
+            project_ids: Filter by project IDs (optional)
+            statuses: Filter by statuses (optional)
+            date_from: Start date for filtering (optional)
+            date_to: End date for filtering (optional)
+            users: Filter by users (optional)
+            groups: Filter by groups (optional)
             statuses: Filter by statuses (optional)
             date_from: Start date filter (optional)
             date_to: End date filter (optional)
@@ -264,6 +307,7 @@ class AuditLogger:
                 timestamp,
                 user,
                 group_name,
+                project_id,
                 query_compressed,
                 status,
                 error_message
@@ -283,6 +327,11 @@ class AuditLogger:
             query += f" AND group_name IN ({placeholders})"
             params.extend(groups)
         
+        if project_ids:
+            placeholders = ','.join('?' * len(project_ids))
+            query += f" AND project_id IN ({placeholders})"
+            params.extend(project_ids)
+        
         if statuses:
             placeholders = ','.join('?' * len(statuses))
             query += f" AND status IN ({placeholders})"
@@ -298,7 +347,7 @@ class AuditLogger:
         
         # Get total count
         count_query = query.replace(
-            "SELECT id, timestamp, user, group_name, query_compressed, status, error_message",
+            "SELECT id, timestamp, user, group_name, project_id, query_compressed, status, error_message",
             "SELECT COUNT(*)"
         )
         
@@ -307,7 +356,8 @@ class AuditLogger:
             
             # Get total count
             cursor.execute(count_query, params)
-            total = cursor.fetchone()[0]
+            result = cursor.fetchone()
+            total = result[0] if result else 0
             
             # Get paginated results
             query += " ORDER BY timestamp DESC LIMIT ? OFFSET ?"
@@ -320,7 +370,7 @@ class AuditLogger:
         logs = []
         for row in rows:
             # Decompress query and get preview (first 100 chars)
-            full_query = self._decompress(row[4])
+            full_query = self._decompress(row[5])
             query_preview = full_query[:100] + "..." if full_query and len(full_query) > 100 else full_query
             
             logs.append({
@@ -328,9 +378,10 @@ class AuditLogger:
                 'timestamp': row[1],
                 'user': row[2],
                 'group': row[3] or '—',
-                'query_preview': query_preview,
-                'status': row[5],
-                'has_error': bool(row[6])
+                'project_id': row[4] or '—',
+                'query_preview': query_preview or '—',
+                'status': row[6],
+                'has_error': bool(row[7])
             })
         
         return logs, total
@@ -349,7 +400,7 @@ class AuditLogger:
             cursor = conn.cursor()
             cursor.execute("""
                 SELECT 
-                    id, timestamp, user, group_name,
+                    id, timestamp, user, group_name, project_id,
                     query_compressed, python_code_compressed, 
                     extracted_data_compressed, status, error_message
                 FROM execution_logs
@@ -366,17 +417,19 @@ class AuditLogger:
             'timestamp': row[1],
             'user': row[2],
             'group': row[3],
-            'query': self._decompress(row[4]),
-            'python_code': self._decompress(row[5]),
-            'extracted_data': self._decompress(row[6]),
-            'status': row[7],
-            'error_message': row[8]
+            'project_id': row[4],
+            'query': self._decompress(row[5]),
+            'python_code': self._decompress(row[6]),
+            'extracted_data': self._decompress(row[7]),
+            'status': row[8],
+            'error_message': row[9]
         }
     
     def get_analytics(
         self,
         date_from: Optional[datetime] = None,
-        date_to: Optional[datetime] = None
+        date_to: Optional[datetime] = None,
+        project_ids: Optional[List[str]] = None
     ) -> Dict[str, Any]:
         """
         Get analytics data for dashboard.
@@ -384,6 +437,7 @@ class AuditLogger:
         Args:
             date_from: Start date for analytics
             date_to: End date for analytics
+            project_ids: Filter by project IDs (optional)
             
         Returns:
             Analytics data dictionary
@@ -399,6 +453,11 @@ class AuditLogger:
             query_base += " AND timestamp <= ?"
             params.append(date_to)
         
+        if project_ids:
+            placeholders = ','.join('?' * len(project_ids))
+            query_base += f" AND project_id IN ({placeholders})"
+            params.extend(project_ids)
+        
         with sqlite3.connect(self.db_path) as conn:
             cursor = conn.cursor()
             
@@ -435,6 +494,19 @@ class AuditLogger:
                 params
             )
             trends = [{'date': row[0], 'count': row[1]} for row in cursor.fetchall()]
+            
+            # Debug logging
+            logger.debug(f"Analytics query returned {len(trends)} trend data points")
+            if len(trends) > 0:
+                logger.debug(f"First trend: {trends[0]}, Last trend: {trends[-1]}")
+            else:
+                logger.warning("No trend data returned from query - checking if data exists")
+                cursor.execute("SELECT COUNT(*), MIN(timestamp), MAX(timestamp) FROM execution_logs WHERE 1=1" + 
+                             (" AND timestamp >= ?" if date_from else "") + 
+                             (" AND timestamp <= ?" if date_to else ""),
+                             [p for p in ([date_from] if date_from else []) + ([date_to] if date_to else [])])
+                count, min_ts, max_ts = cursor.fetchone()
+                logger.warning(f"Total logs: {count}, Date range: {min_ts} to {max_ts}")
         
         return {
             'total_executions': total_executions,
@@ -447,7 +519,7 @@ class AuditLogger:
         }
     
     def get_distinct_values(self) -> Dict[str, List[str]]:
-        """Get distinct users, groups, and statuses for filter dropdowns."""
+        """Get distinct users, groups, project IDs, and statuses for filter dropdowns."""
         with sqlite3.connect(self.db_path) as conn:
             cursor = conn.cursor()
             
@@ -456,14 +528,13 @@ class AuditLogger:
             users = [row[0] for row in cursor.fetchall()]
             
             # Get distinct groups (excluding NULL)
-            cursor.execute("""
-                SELECT DISTINCT group_name 
-                FROM execution_logs 
-                WHERE group_name IS NOT NULL 
-                ORDER BY group_name
-            """)
+            cursor.execute("SELECT DISTINCT group_name FROM execution_logs WHERE group_name IS NOT NULL ORDER BY group_name")
             groups = [row[0] for row in cursor.fetchall()]
             
+            # Get distinct project IDs (excluding NULL)
+            cursor.execute("SELECT DISTINCT project_id FROM execution_logs WHERE project_id IS NOT NULL ORDER BY project_id")
+            project_ids = [row[0] for row in cursor.fetchall()]
+            
             # Get distinct statuses
             cursor.execute("SELECT DISTINCT status FROM execution_logs ORDER BY status")
             statuses = [row[0] for row in cursor.fetchall()]
@@ -471,6 +542,7 @@ class AuditLogger:
         return {
             'users': users,
             'groups': groups,
+            'project_ids': project_ids,
             'statuses': statuses
         }
     
