@@ -10,6 +10,7 @@ import json
 from pathlib import Path
 
 from ..utils.audit_logger import AuditLogger
+from ..utils.env_manager import EnvPresetManager
 from .auth import AuthManager
 from ..config.runtime_config import get_web_config, save_web_config
 
@@ -65,9 +66,17 @@ def create_app(config: dict) -> Flask:
         managed_projects=config.get('MANAGED_PROJECTS', None)
     )
     
+    # Initialize environment preset manager
+    env_db_path = config.get('ENV_DB_PATH', config['AUDIT_DB_PATH'].replace('audit_logs.db', 'env_presets.db'))
+    env_manager = EnvPresetManager(
+        db_path=env_db_path,
+        secret_key=config.get('SECRET_KEY', '')
+    )
+    
     # Store in app config for access in routes
     app.config['audit_logger'] = audit_logger
     app.config['auth_manager'] = auth_manager
+    app.config['env_manager'] = env_manager
     app.config['audit_config'] = config
     app.config['WEB_HOST'] = config.get('WEB_INTERFACE_HOST', '127.0.0.1')
     app.config['WEB_PORT'] = config.get('WEB_INTERFACE_PORT', 8080)
@@ -365,6 +374,253 @@ def create_app(config: dict) -> Flask:
             logger.error(f"Error updating web configuration: {e}")
             return jsonify({'success': False, 'error': str(e)}), 400
     
+    # ===== Environment Presets API Routes =====
+    
+    @app.route('/api/env/presets', methods=['GET'])
+    @login_required
+    def api_get_env_presets():
+        """Get all environment presets (values masked)."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            presets = env_manager.get_presets(include_var_count=True)
+            return jsonify({'presets': presets})
+        except Exception as e:
+            logger.error(f"Error getting presets: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/presets', methods=['POST'])
+    @login_required
+    def api_create_env_preset():
+        """Create a new environment preset."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            data = request.get_json()
+            preset_name = data.get('preset_name', '').strip()
+            project_id = data.get('project_id')
+            description = data.get('description', '').strip()
+            variables = data.get('variables', [])
+            
+            if not preset_name:
+                return jsonify({'error': 'Preset name is required'}), 400
+            
+            # Validate variables
+            for var in variables:
+                key = var.get('key', '').strip()
+                if key:  # Only validate non-empty keys
+                    is_valid, error = env_manager.validate_key_name(key)
+                    if not is_valid:
+                        return jsonify({'error': error, 'invalid_key': key}), 400
+            
+            preset_id = env_manager.create_preset(
+                preset_name=preset_name,
+                created_by=request.username,
+                project_id=project_id if project_id else None,
+                description=description if description else None,
+                variables=variables
+            )
+            
+            return jsonify({'success': True, 'preset_id': preset_id})
+        except ValueError as e:
+            return jsonify({'error': str(e)}), 400
+        except Exception as e:
+            logger.error(f"Error creating preset: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/presets/<int:preset_id>', methods=['GET'])
+    @login_required
+    def api_get_env_preset(preset_id):
+        """Get a specific preset (values masked by default)."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            preset = env_manager.get_preset(preset_id, mask_values=True)
+            
+            if not preset:
+                return jsonify({'error': 'Preset not found'}), 404
+            
+            return jsonify(preset)
+        except Exception as e:
+            logger.error(f"Error getting preset {preset_id}: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/presets/<int:preset_id>', methods=['PUT'])
+    @login_required
+    def api_update_env_preset(preset_id):
+        """Update preset metadata or variables."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            data = request.get_json()
+            
+            # Check if updating variables or metadata
+            if 'variables' in data:
+                # Update variables
+                variables = data['variables']
+                
+                # Validate variables
+                for var in variables:
+                    key = var.get('key', '').strip()
+                    if key:
+                        is_valid, error = env_manager.validate_key_name(key)
+                        if not is_valid:
+                            return jsonify({'error': error, 'invalid_key': key}), 400
+                
+                env_manager.update_variables(preset_id, variables)
+            else:
+                # Update metadata
+                preset_name = data.get('preset_name')
+                project_id = data.get('project_id')
+                description = data.get('description')
+                
+                env_manager.update_preset(
+                    preset_id,
+                    preset_name=preset_name,
+                    project_id=project_id,
+                    description=description
+                )
+            
+            return jsonify({'success': True})
+        except ValueError as e:
+            return jsonify({'error': str(e)}), 400
+        except Exception as e:
+            logger.error(f"Error updating preset {preset_id}: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/presets/<int:preset_id>', methods=['DELETE'])
+    @login_required
+    def api_delete_env_preset(preset_id):
+        """Delete an entire preset."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            success = env_manager.delete_preset(preset_id)
+            
+            if success:
+                return jsonify({'success': True})
+            else:
+                return jsonify({'error': 'Preset not found'}), 404
+        except Exception as e:
+            logger.error(f"Error deleting preset {preset_id}: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/presets/<int:preset_id>/variables/<int:variable_id>', methods=['DELETE'])
+    @login_required
+    def api_delete_env_variable(preset_id, variable_id):
+        """Delete a single variable from a preset."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            success = env_manager.delete_variable(preset_id, variable_id)
+            
+            if success:
+                return jsonify({'success': True})
+            else:
+                return jsonify({'error': 'Variable not found'}), 404
+        except Exception as e:
+            logger.error(f"Error deleting variable {variable_id}: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/authenticate-view', methods=['POST'])
+    @login_required
+    def api_authenticate_env_view():
+        """Authenticate to view unmasked environment values (10-min session)."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            data = request.get_json()
+            password = data.get('password')
+            
+            if not password:
+                return jsonify({'error': 'Password required'}), 400
+            
+            # Authenticate user with password
+            if not auth_manager.verify_password(request.username, password):
+                return jsonify({'error': 'Invalid password'}), 401
+            
+            # Create view session
+            session_token = env_manager.create_view_session(request.username)
+            
+            return jsonify({
+                'success': True,
+                'session_token': session_token,
+                'expires_in_minutes': env_manager.VIEW_SESSION_DURATION_MINUTES
+            })
+        except Exception as e:
+            logger.error(f"Error authenticating view session: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/presets/<int:preset_id>/reveal', methods=['GET'])
+    @login_required
+    def api_reveal_env_preset(preset_id):
+        """Get preset with unmasked values (requires view session token)."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            # Get session token from header
+            session_token = request.headers.get('X-View-Session-Token')
+            
+            if not session_token:
+                return jsonify({'error': 'View session token required'}), 401
+            
+            # Validate session
+            username = env_manager.validate_view_session(session_token)
+            
+            if not username or username != request.username:
+                return jsonify({'error': 'Invalid or expired view session'}), 401
+            
+            # Get preset with unmasked values
+            preset = env_manager.get_preset(preset_id, mask_values=False)
+            
+            if not preset:
+                return jsonify({'error': 'Preset not found'}), 404
+            
+            return jsonify(preset)
+        except Exception as e:
+            logger.error(f"Error revealing preset {preset_id}: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    @app.route('/api/env/validate-key', methods=['POST'])
+    @login_required
+    def api_validate_env_key():
+        """Validate an environment variable key name."""
+        try:
+            env_manager = app.config.get('env_manager')
+            if not env_manager:
+                return jsonify({'error': 'Environment presets not initialized'}), 500
+            
+            data = request.get_json()
+            key = data.get('key', '').strip()
+            
+            is_valid, error = env_manager.validate_key_name(key)
+            
+            return jsonify({
+                'valid': is_valid,
+                'error': error if not is_valid else None
+            })
+        except Exception as e:
+            logger.error(f"Error validating key: {e}")
+            return jsonify({'error': str(e)}), 500
+    
+    # ===== End Environment Presets API =====
+    
     # Security: Reject all undefined routes
     @app.errorhandler(404)
     def not_found(e):
