@@ -202,6 +202,36 @@ class AuthManager:
             
             return username
     
+    def verify_password(self, username: str, password: str) -> bool:
+        """
+        Verify a user's password without creating a session.
+        
+        Args:
+            username: Username
+            password: Password to verify
+            
+        Returns:
+            True if password is correct, False otherwise
+        """
+        with sqlite3.connect(self.db_path) as conn:
+            cursor = conn.cursor()
+            cursor.execute("""
+                SELECT password_hash FROM users WHERE username = ?
+            """, (username,))
+            
+            row = cursor.fetchone()
+            
+            if not row:
+                return False
+            
+            password_hash = row[0]
+            
+            # Verify password
+            return bcrypt.checkpw(password.encode('utf-8'), password_hash)
+                return None
+            
+            return username
+    
     def logout(self, session_token: str):
         """
         Logout user by invalidating session.
